@@ -156,7 +156,6 @@ and Gnus and BBDB maps."
 
 (defun gnorb-follow-gnus-link (group id)
   "Be a little clever about following gnus links.
-
 The goal here is reuse frames and windows as much as possible, so
 we're not opening multiple windows on the *Group* buffer, for
 instance, and messing up people's layouts. There also seems to be
@@ -211,16 +210,13 @@ window."
   ;; called from elsewhere...
   (let* ((id (gnorb-bracket-message-id id))
 	 (arts (gnus-group-unread group))
-	 artno success)
-    (or (setq artno (car (gnus-registry-get-id-key id 'artno)))
-	(progn
-	  (setq artno (cdr (gnus-request-head id group)))
-	  (gnus-registry-set-id-key id 'artno (list artno))))
+	 (artno (cdr (gnus-request-head id group)))
+	 success)
     (gnus-activate-group group)
     (setq success (gnus-group-read-group arts t group))
     (if success
 	(gnus-summary-goto-article artno nil t)
-      (signal 'error "Group could not be opened."))))
+      (signal 'error (format "Group %s could not be opened." group)))))
 
 ;; I'd like to suggest this as a general addition to Emacs.  *Very*
 ;; tired of abusing `completing-read' for this purpose.
@@ -326,6 +322,7 @@ numbers (no upper bound)."
 we were in the agenda when this was called, then keep us in the
 agenda. Then let the user choose an action from the value of
 `gnorb-org-trigger-actions'."
+  (require 'gnorb-org)
   (let* ((agenda-p (eq major-mode 'org-agenda-mode))
 	 (root-marker
 	  (cond (agenda-p
@@ -519,7 +516,12 @@ methods?"
 				   gnorb-gnus-sent-groups)))
 	(while (setq server-group (pop candidates))
 	  (when (and (stringp server-group)
-		     (string-match-p "+" server-group)
+		     ;; I don't remember the reason for this check,
+		     ;; which is totally fragile and fails on groups
+		     ;; belonging to `gnus-select-method': another
+		     ;; reason why this select method stuff is a mess.
+
+		     ;;(string-match-p "+" server-group)
 		     (not
 		      (string-match-p
 		       "\\(nnir\\|nnvirtual\\|UNKNOWN\\)"
@@ -535,7 +537,6 @@ methods?"
 
 (defun gnorb-collect-ids (&optional id)
   "Collect all Org IDs for a subtree.
-
 Starting with the heading under point (or the heading indicated
 by the ID argument), collect its ID property, and the IDs of all
 child headings."
@@ -636,7 +637,7 @@ registry be in use, and should be called after the call to
        (define-key bbdb-mode-map (kbd "C-c l") #'gnorb-bbdb-open-link)
        (define-key bbdb-mode-map [remap bbdb-mail] #'gnorb-bbdb-mail)
        (eval-after-load "gnorb-org"
-	 (org-defkey org-mode-map (kbd "C-c C") #'gnorb-org-contact-link))))
+	 '(org-defkey org-mode-map (kbd "C-c C") #'gnorb-org-contact-link))))
   (eval-after-load "gnorb-org"
     '(progn
        (org-defkey org-mode-map (kbd "C-c t") #'gnorb-org-handle-mail)
